{% if error %}
    {% for message in messages %}
        <div class="label label-danger">
            {{message}}
        </div>
    {% endfor %}
    {% for message in value_messages %}
        <div class="label label-danger">
            {{message}}
        </div>
    {% endfor %}
{% endif %}
