<div class="form-group custom-combobox">
    <label>{{label}}:</label>
    {% include templates['field_error'] %}

    <input
            class="form-control"
            value="{{value}}"
            name="{{name}}"
            id="{{id}}"
            {%- if disabled %} disabled=disabled {% endif -%}
            >
    <ul id="{{id}}_list">
        {%- for element in field.avalible_values -%}
            {%- if element['value'] != '' -%}
                <li>{{element['label']}}</li>
            {%- endif -%}
        {%- endfor -%}
    </ul>
</div>
