<div class="form-group">
    <label>{{label}}:</label>
    {% include templates['field_error'] %}

    <input
        class="form-control"
        value="{{value}}"
        name="{{name}}"
        id="{{id}}"
        {%- if disabled %} disabled=disabled {% endif -%}
        >
</div>
