<div class="form-group">
    <label>{{label}}:</label>
    {% include templates['field_error'] %}
    <input
        class="form-control"
        name="{{name}}"
        id="{{id}}"
        type="password"
        {%- if disabled %} disabled=disabled {% endif -%}
        {%- if autofocus %} autofocus{% endif -%}
        >
</div>
