<form method="post" enctype="multipart/form-data" role="form" {% if action != None -%}
        action="{{action}}"
    {%- endif -%}
    {%- if style != None %}
        style="{{style}}"
    {%- endif -%}
    {%- if class != None %}
        class="{{class}}"
    {%- endif -%}
    {%- if id %} id="{{id}}"{% endif -%}
    >
    <input type="hidden" name="form_name" value="{{name}}" />
    {{widget.csrf_token()}}
